@@ -11,37 +11,37 @@ class Holder():
     fileMaxLength = 0
     clipBoard = ""
     
-    def setFiles(self, files: list):
+    def setFiles(self, files: list) -> None:
         self.files = files
     
-    def setArgs(self, args: list):
+    def setArgs(self, args: list) -> None:
         self.args = args
         self.args_id = [x[0] for x in self.args]
         self.reversed = ARGS_REVERSE in self.args_id
     
-    def __count_generator__(self, reader):
+    def __count_generator__(self, reader) -> bytes:
         b = reader(1024 * 1024)
         while b:
             yield b
             b = reader(1024 * 1024)
         
-    def __getFileLinesSum__(self, file):
+    def __getFileLinesSum__(self, file) -> int:
         with open(file, 'rb') as fp:
             c_generator = self.__count_generator__(fp.raw.read)
             count = sum(buffer.count(b'\n') for buffer in c_generator)
             return count + 1
     
-    def __calcFilesLineSum__(self):
+    def __calcFilesLineSum__(self) -> None:
         self.lineSum = sum([self.__getFileLinesSum__(file) for file in self.files])
         self.fileCount = self.lineSum if self.reversed else 0
         
-    def __calcFileLineMaxLength__(self):
+    def __calcFileLineMaxLength__(self) -> None:
         self.fileLineMaxLength = len(str(self.fileCount)) if self.reversed else len(str(self.lineSum))
 
-    def __calcFileMaxLength__(self):
+    def __calcFileMaxLength__(self) -> None:
         self.fileMaxLength = len(str(len(self.files)))
         
-    def generateValues(self):
+    def generateValues(self) -> None:
         self.__calcFilesLineSum__()
         self.__calcFileLineMaxLength__()
         self.__calcFileMaxLength__()
\ No newline at end of file
